#
# spec file for package libnova
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define so_ver 0_15-0

Name:           libnova
Version:        0.15.0
Release:        11.1
Summary:        Celestial Mechanics, Astrometry and Astrodynamics Library
License:        LGPL-2.0+
Group:          System/Libraries
Url:            http://libnova.sourceforge.net/
Source0:        http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM automake-1.13.patch asterios.dramis@gmail.com -- Fix build with automake 1.13
Patch0:         automake-1.13.patch
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
libnova is a general purpose, double precision, Celestial Mechanics,
Astrometry and Astrodynamics library. The intended audience of libnova
is C & C++ programmers, astronomers and anyone else interested in
calculating positions of astronomical objects or celestial mechanics.

%package devel
Summary:        Development files for libnova
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libnova-%{so_ver} = %{version}

%description devel
This package contains development files for libnova.

%package -n libnova-%{so_ver}
Summary:        Celestial Mechanics, Astrometry and Astrodynamics Library
Group:          System/Libraries

%description -n libnova-%{so_ver}
libnova is a general purpose, double precision, Celestial Mechanics,
Astrometry and Astrodynamics library. The intended audience of libnova
is C & C++ programmers, astronomers and anyone else interested in
calculating positions of astronomical objects or celestial mechanics.

%prep
%autosetup -p0

%build
# Regenerate build system because of errors about libtool during compilation
autoreconf -vif
echo 'HTML_TIMESTAMP=NO' >> doc/doxyfile.in
%configure --disable-static --with-pic
make CFLAGS+="%{optflags}" %{?_smp_mflags}
cd doc
make doc %{?_smp_mflags}
cd ..

%install
make DESTDIR=%{buildroot} install

# Manually install doc files in order to fix rpmlint warning "files-duplicate"
mkdir -p %{buildroot}%{_docdir}/%{name}-devel
cp -a doc/html/ %{buildroot}%{_docdir}/%{name}-devel/
cp -a AUTHORS COPYING ChangeLog NEWS %{buildroot}%{_docdir}/%{name}-devel/

# Remove libtool config files
rm -f %{buildroot}%{_libdir}/*.la

%fdupes -s %{buildroot}

%post -n libnova-%{so_ver} -p /sbin/ldconfig

%postun -n libnova-%{so_ver} -p /sbin/ldconfig

%files devel
%defattr(-,root,root,-)
%doc %{_docdir}/%{name}-devel/
%{_includedir}/libnova/
%{_libdir}/libnova.so
%{_bindir}/libnovaconfig

%files -n libnova-%{so_ver}
%defattr(-,root,root,-)
%{_libdir}/libnova-0.15.so.0*

%changelog
* Thu Feb 29 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Wed May 28 2014 crrodriguez@opensuse.org
- disable doxyegn timestamps that break build-compare.
* Fri Mar 22 2013 asterios.dramis@gmail.com
- Added a patch "automake-1.13.patch" to fix build with automake 1.13.
* Tue Nov 20 2012 nico.kruber@gmail.com
- Fix the SLES build (%%make_install is not expanded on SLES)
* Sat Sep 22 2012 asterios.dramis@gmail.com
- Update to version 0.15.0:
  * Bugfix release.
- Regenerate build system because of errors about libtool during compilation
  (added libtool build requirement for this).
- Compile developer documentation (added doxygen build requirement for this).
* Wed Aug 31 2011 asterios.dramis@gmail.com
- Update to version 0.14.0:
  * Various bugfixes.
- Spec file updates:
  * Changed License: to LGPL-2.0+.
  * Minor other updates.
* Fri May 20 2011 asterios.dramis@gmail.com
- Update to version 0.13.0:
  * Added heliocentric time corrections calculations.
  * Various bugfixes.
  * Sun/Solaris support fixes.
  From 0.12.3:
  * MS Windows support fixes.
- Spec file updates:
  * Changes based on spec-cleaner run.
  * Changed License: to LGPLv2+.
  * Updates in Summary: and Group entries.
  * Removed %%changelog entries.
  * Minor other updates.
- Removed libnova-0.12.2-optflags.patch and replaced it with a fix inside the
  spec file.
* Tue May 19 2009 dmueller@suse.de
- fix debuginfo package requires
* Wed Mar 11 2009 crrodriguez@suse.de
-  remove static libraries an "la" files
- fix devel package dependencies
- use RPM_OPT_FLAGS
* Tue Jan  6 2009 dmueller@suse.de
- Initial version (0.12.2)
